/* Use this header with source C backend */
#ifndef AUTOREVISION_DECLR_H
#define AUTOREVISION_DECLR_H

extern const char *VCS_TYPE;
extern const char *VCS_BASENAME;
extern const char *VCS_UUID;
extern const int VCS_NUM;
extern const char *VCS_DATE;
extern const char *VCS_BRANCH;
extern const char *VCS_TAG;
extern const char *VCS_TAG_OPENPGP;
extern const int VCS_TICK;
extern const char *VCS_EXTRA;

extern const char *VCS_ACTION_STAMP;
extern const char *VCS_FULL_HASH;
extern const char *VCS_COMMIT_OPENPGP;
extern const char *VCS_SHORT_HASH;

extern const int VCS_WC_MODIFIED;

#endif
